.. _contents:

#################################
 Camelot Documentation contents
#################################

.. toctree::

   tutorial/index.rst
   doc/index.rst

   glossary.rst
   license.rst
   copyright.rst
